@@ -91,7 +91,9 @@ pub mod build {
 
   #[allow(non_camel_case_types)]
   mod method {
+    #[derive(Copy, Clone, Debug)]
     pub struct action_id;
+    #[derive(Copy, Clone, Debug)]
     pub struct options;
   }
 
@@ -129,6 +131,7 @@ pub mod build {
   ///
   /// // <send block to slack API>
   /// ```
+  #[derive(Debug)]
   pub struct RadioBuilder<'a, T, A, O> {
     action_id: Option<Cow<'a, str>>,
     options: Option<Vec<MyOpt<'a>>>,
