@@ -295,8 +295,11 @@ pub mod build {
 
   #[allow(non_camel_case_types)]
   pub mod method {
+    #[derive(Copy, Clone, Debug)]
     pub struct placeholder;
+    #[derive(Copy, Clone, Debug)]
     pub struct initial_option;
+    #[derive(Copy, Clone, Debug)]
     pub struct action_id;
   }
 
@@ -336,7 +339,7 @@ pub mod build {
   ///
   /// // <send block to API>
   /// ```
-  #[derive(Default)]
+  #[derive(Debug)]
   pub struct ExternalBuilder<'a, Multi, Placeholder, ActionId, Options> {
     placeholder: Option<text::Text>,
     action_id: Option<Cow<'a, str>>,
