@@ -131,8 +131,11 @@ pub mod build {
 
   #[allow(non_camel_case_types)]
   pub mod method {
+    #[derive(Copy, Clone, Debug)]
     pub struct placeholder;
+    #[derive(Copy, Clone, Debug)]
     pub struct options;
+    #[derive(Copy, Clone, Debug)]
     pub struct action_id;
   }
 
@@ -175,7 +178,7 @@ pub mod build {
   ///
   /// // <send block to API>
   /// ```
-  #[derive(Default)]
+  #[derive(Debug)]
   pub struct StaticBuilder<'a, Multi, Placeholder, ActionId, Options> {
     placeholder: Option<text::Text>,
     action_id: Option<Cow<'a, str>>,
